@@ -26,7 +26,6 @@
 #include "gdk-pixbuf-private.h"
 #include "io-ani-animation.h"
 
-static void gdk_pixbuf_ani_anim_class_init (GdkPixbufAniAnimClass *klass);
 static void gdk_pixbuf_ani_anim_finalize   (GObject        *object);
 
 static gboolean                gdk_pixbuf_ani_anim_is_static_image  (GdkPixbufAnimation *animation);
@@ -40,32 +39,11 @@ static GdkPixbufAnimationIter* gdk_pixbuf_ani_anim_get_iter (GdkPixbufAnimation
 
 
 
-static gpointer parent_class;
+G_DEFINE_TYPE  (GdkPixbufAniAnim, gdk_pixbuf_ani_anim, GDK_TYPE_PIXBUF_ANIMATION)
 
-GType
-gdk_pixbuf_ani_anim_get_type (void)
+static void
+gdk_pixbuf_ani_anim_init (GdkPixbufAniAnim *anim)
 {
-        static GType object_type = 0;
-
-        if (!object_type) {
-                const GTypeInfo object_info = {
-                        sizeof (GdkPixbufAniAnimClass),
-                        (GBaseInitFunc) NULL,
-                        (GBaseFinalizeFunc) NULL,
-                        (GClassInitFunc) gdk_pixbuf_ani_anim_class_init,
-                        NULL,           /* class_finalize */
-                        NULL,           /* class_data */
-                        sizeof (GdkPixbufAniAnim),
-                        0,              /* n_preallocs */
-                        (GInstanceInitFunc) NULL,
-                };
-                
-                object_type = g_type_register_static (GDK_TYPE_PIXBUF_ANIMATION,
-                                                      g_intern_static_string ("GdkPixbufAniAnim"),
-                                                      &object_info, 0);
-        }
-        
-        return object_type;
 }
 
 static void
@@ -73,9 +51,7 @@ gdk_pixbuf_ani_anim_class_init (GdkPixbufAniAnimClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
         GdkPixbufAnimationClass *anim_class = GDK_PIXBUF_ANIMATION_CLASS (klass);
-        
-        parent_class = g_type_class_peek_parent (klass);
-        
+
         object_class->finalize = gdk_pixbuf_ani_anim_finalize;
 
         anim_class->is_static_image = gdk_pixbuf_ani_anim_is_static_image;
@@ -97,12 +73,12 @@ gdk_pixbuf_ani_anim_finalize (GObject *object)
         g_free (ani_anim->pixbufs);
         g_free (ani_anim->sequence);
         g_free (ani_anim->delay);
-        
-        G_OBJECT_CLASS (parent_class)->finalize (object);
+
+        G_OBJECT_CLASS (gdk_pixbuf_ani_anim_parent_class)->finalize (object);
 }
 
 static gboolean
-gdk_pixbuf_ani_anim_is_static_image  (GdkPixbufAnimation *animation)
+gdk_pixbuf_ani_anim_is_static_image (GdkPixbufAnimation *animation)
 {
         GdkPixbufAniAnim *ani_anim;
 
@@ -121,7 +97,7 @@ gdk_pixbuf_ani_anim_get_static_image (GdkPixbufAnimation *animation)
         if (ani_anim->pixbufs == NULL)
                 return NULL;
         else
-                return ani_anim->pixbufs[0];        
+                return ani_anim->pixbufs[0];
 }
 
 static void
@@ -144,7 +120,7 @@ gdk_pixbuf_ani_anim_get_size (GdkPixbufAnimation *anim,
 static void
 iter_restart (GdkPixbufAniAnimIter *iter)
 {
-        iter->current_frame = 0;        
+        iter->current_frame = 0;
         iter->position = 0;
         iter->elapsed = 0;
 }
@@ -160,18 +136,17 @@ gdk_pixbuf_ani_anim_get_iter (GdkPixbufAnimation *anim,
         iter->ani_anim = GDK_PIXBUF_ANI_ANIM (anim);
 
         g_object_ref (iter->ani_anim);
-        
+
         iter_restart (iter);
 
         iter->start_time = *start_time;
         iter->current_time = *start_time;
-        
+
         return GDK_PIXBUF_ANIMATION_ITER (iter);
 }
 
 
 
-static void gdk_pixbuf_ani_anim_iter_class_init (GdkPixbufAniAnimIterClass *klass);
 static void gdk_pixbuf_ani_anim_iter_finalize   (GObject                   *object);
 
 static int        gdk_pixbuf_ani_anim_iter_get_delay_time             (GdkPixbufAnimationIter *iter);
@@ -182,32 +157,11 @@ static gboolean   gdk_pixbuf_ani_anim_iter_advance                    (GdkPixbuf
 
 
 
-static gpointer iter_parent_class;
+G_DEFINE_TYPE (GdkPixbufAniAnimIter, gdk_pixbuf_ani_anim_iter, GDK_TYPE_PIXBUF_ANIMATION_ITER);
 
-GType
-gdk_pixbuf_ani_anim_iter_get_type (void)
+static void
+gdk_pixbuf_ani_anim_iter_init (GdkPixbufAniAnimIter *anim)
 {
-        static GType object_type = 0;
-
-        if (!object_type) {
-                const GTypeInfo object_info = {
-                        sizeof (GdkPixbufAniAnimIterClass),
-                        (GBaseInitFunc) NULL,
-                        (GBaseFinalizeFunc) NULL,
-                        (GClassInitFunc) gdk_pixbuf_ani_anim_iter_class_init,
-                        NULL,           /* class_finalize */
-                        NULL,           /* class_data */
-                        sizeof (GdkPixbufAniAnimIter),
-                        0,              /* n_preallocs */
-                        (GInstanceInitFunc) NULL,
-                };
-                
-                object_type = g_type_register_static (GDK_TYPE_PIXBUF_ANIMATION_ITER,
-                                                      g_intern_static_string ("GdkPixbufAniAnimIter"),
-                                                      &object_info, 0);
-        }
-        
-        return object_type;
 }
 
 static void
@@ -216,9 +170,7 @@ gdk_pixbuf_ani_anim_iter_class_init (GdkPixbufAniAnimIterClass *klass)
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
         GdkPixbufAnimationIterClass *anim_iter_class =
                 GDK_PIXBUF_ANIMATION_ITER_CLASS (klass);
-        
-        iter_parent_class = g_type_class_peek_parent (klass);
-        
+
         object_class->finalize = gdk_pixbuf_ani_anim_iter_finalize;
 
         anim_iter_class->get_delay_time = gdk_pixbuf_ani_anim_iter_get_delay_time;
@@ -233,8 +185,8 @@ gdk_pixbuf_ani_anim_iter_finalize (GObject *object)
         GdkPixbufAniAnimIter *iter = GDK_PIXBUF_ANI_ANIM_ITER (object);
 
         g_object_unref (iter->ani_anim);
-        
-        G_OBJECT_CLASS (iter_parent_class)->finalize (object);
+
+        G_OBJECT_CLASS (gdk_pixbuf_ani_anim_iter_parent_class)->finalize (object);
 }
 
 static gboolean
@@ -247,7 +199,7 @@ gdk_pixbuf_ani_anim_iter_advance (GdkPixbufAnimationIter *anim_iter,
         gint old;
 
         iter = GDK_PIXBUF_ANI_ANIM_ITER (anim_iter);
-        
+
         iter->current_time = *current_time;
 
         /* We use milliseconds for all times */
@@ -264,16 +216,16 @@ gdk_pixbuf_ani_anim_iter_advance (GdkPixbufAnimationIter *anim_iter,
         }
 
         g_assert (iter->ani_anim->total_time > 0);
-        
+
         /* See how many times we've already played the full animation,
          * and subtract time for that.
          */
         elapsed = elapsed % iter->ani_anim->total_time;
 
         iter->position = elapsed;
-        
+
         /* Now move to the proper frame */
-        
+
         iter->elapsed = 0;
         for (tmp = 0; tmp < iter->ani_anim->n_frames; tmp++) {
                 if (iter->position >= iter->elapsed &&
@@ -283,7 +235,7 @@ gdk_pixbuf_ani_anim_iter_advance (GdkPixbufAnimationIter *anim_iter,
         }
 
         old = iter->current_frame;
-        
+
         iter->current_frame = tmp;
 
         return iter->current_frame != old;
@@ -293,7 +245,7 @@ int
 gdk_pixbuf_ani_anim_iter_get_delay_time (GdkPixbufAnimationIter *anim_iter)
 {
         GdkPixbufAniAnimIter *iter;
-  
+
         iter = GDK_PIXBUF_ANI_ANIM_ITER (anim_iter);
 
         return iter->ani_anim->delay[iter->current_frame] - (iter->position - iter->elapsed);
@@ -323,13 +275,13 @@ gdk_pixbuf_ani_anim_iter_on_currently_loading_frame (GdkPixbufAnimationIter *ani
         gint frame;
 
         iter = GDK_PIXBUF_ANI_ANIM_ITER (anim_iter);
-      
+
         if (iter->current_frame >= iter->ani_anim->n_frames - 1)
                 return TRUE;
-        
+
         frame = iter->ani_anim->sequence[iter->current_frame + 1];
 
-        if (!iter->ani_anim->pixbufs[frame]) 
+        if (!iter->ani_anim->pixbufs[frame])
                 return TRUE;
 
         return FALSE;
